summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'scripts/gentoo/make-tarball.sh')
-rwxr-xr-xscripts/gentoo/make-tarball.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/scripts/gentoo/make-tarball.sh b/scripts/gentoo/make-tarball.sh
index bb45835e1f..094f16c27c 100755
--- a/scripts/gentoo/make-tarball.sh
+++ b/scripts/gentoo/make-tarball.sh
@@ -69,8 +69,9 @@ cp scripts/gentoo/README.Gentoo.patches tmp/ || exit 1
git format-patch glibc-${PV}..HEAD > /dev/null
# remove all patches where the summary line starts with [no-tarball]
rm -f 00??-no-tarball-*.patch
+rm -f 00??-no-patch-*.patch
for myname in 00*.patch ; do
mv ${myname} tmp/patches/$(echo ${myname}|sed -e 's:^\(....\)-:\1_all_:') || exit 1
@@ -69,8 +69,9 @@ cp scripts/gentoo/README.Gentoo.patches tmp/ || exit 1
git format-patch glibc-${PV}..HEAD > /dev/null
-# remove all patches where the summary line starts with [no-tarball]
+# remove all patches where the summary line starts with [no-tarball] or [no-patch]
rm -f 00??-no-tarball-*.patch